@@ -50,6 +50,7 @@ use internals::{get_configuration, set_configuration};
 
 pub use crate::compiler::Compiler;
 pub use crate::errors::*;
+pub use crate::flags::ScanFlags;
 use crate::initialize::InitializationToken;
 pub use crate::matches::Match;
 pub use crate::rules::{Metadata, MetadataValue, Rule, Rules};
@@ -58,7 +59,6 @@ pub use crate::string::YrString;
 pub use internals::{
     CallbackMsg, CallbackReturn, MemoryBlock, MemoryBlockIterator, MemoryBlockIteratorSized,
 };
-pub use yara_sys::scan_flags::*;
 
 mod compiler;
 mod initialize;
@@ -69,6 +69,7 @@ mod scanner;
 mod string;
 
 pub mod errors;
+mod flags;
 
 /// Yara initialization token.
 ///
